pub enum LogLevel {
Trace,
Debug,
Info,
Warn,
Error,
}Expand description
Determines the severity of a log message.
Variants
Trace
Describes messages about the values of variables and the flow of control within a program.
Debug
Describes messages likely to be of interest to someone debugging a program.
Info
Describes messages likely to be of interest to someone monitoring a program.
Warn
Describes messages indicating hazardous situations.
Error
Describes messages indicating serious errors.